@@ -1,4 +1,4 @@
-/* xml++.cc
+/* parser.cc
  * libxml++ and this file are copyright (C) 2000 by Ari Johnson, and
  * are covered by the GNU Lesser General Public License, which should be
  * included with libxml++ as the file COPYING.
@@ -9,6 +9,7 @@
 #include <libxml/parser.h>
 
 #include <cstdarg> //For va_list.
+#include <memory> //For auto_ptr.
 
 namespace xmlpp {
 
